use axum::response::{Html, IntoResponse};
use http::StatusCode;
use maud::{html, Markup, DOCTYPE};

pub struct MarkupResponse {
    title: String,
    body: Markup,
}

impl MarkupResponse {
    pub fn new(body: Markup, title: &str) -> Self {
        Self {
            title: title.to_owned(),
            body,
        }
    }
}

impl IntoResponse for MarkupResponse {
    fn into_response(self) -> axum::response::Response {
        Html::from(base_page(&self.title, &self.body).into_string()).into_response()
    }
}

fn base_page(title: &str, markup: &Markup) -> Markup {
    html! {
        (DOCTYPE)
        html lang="en" {
            head {
                meta charset="utf-8";
                meta name="viewport"  content="width=device-width, initial-scale=1";
                title { (title) }
                // link rel="stylesheet" href="/style";
            }
            body { (markup) }
        }
    }
}

pub fn simple_error_page(status: StatusCode) -> MarkupResponse {
    MarkupResponse::new(
        html! {
            img src=(format!("https://http.cat/{}", status.as_u16()));
        },
        "Error",
    )
}
